| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.SecretsManager.Types.Tag
Description
Documentation
A structure that contains information about a tag.
See: newTag smart constructor.
Constructors
| Tag' | |
Instances
| FromJSON Tag Source # | |
| ToJSON Tag Source # | |
Defined in Amazonka.SecretsManager.Types.Tag | |
| Generic Tag Source # | |
| Read Tag Source # | |
| Show Tag Source # | |
| NFData Tag Source # | |
Defined in Amazonka.SecretsManager.Types.Tag | |
| Eq Tag Source # | |
| Hashable Tag Source # | |
Defined in Amazonka.SecretsManager.Types.Tag | |
| type Rep Tag Source # | |
Defined in Amazonka.SecretsManager.Types.Tag type Rep Tag = D1 ('MetaData "Tag" "Amazonka.SecretsManager.Types.Tag" "amazonka-secretsmanager-2.0-8tljeZ4CwL92E7JavkDb0o" 'False) (C1 ('MetaCons "Tag'" 'PrefixI 'True) (S1 ('MetaSel ('Just "key") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)) :*: S1 ('MetaSel ('Just "value") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedStrict) (Rec0 (Maybe Text)))) | |
Create a value of Tag with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:key:Tag', tag_key - The key identifier, or name, of the tag.
$sel:value:Tag', tag_value - The string value associated with the key of the tag.